# CohortResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model_jobs** | [**list[CohortJoinedModelJobResponseDto]**](CohortJoinedModelJobResponseDto.md) |  | [optional] 
**train_cohort** | [**CohortJoinedCohortResponseDto**](CohortJoinedCohortResponseDto.md) |  | [optional] 
**prediction_cohorts** | [**list[CohortJoinedCohortResponseDto]**](CohortJoinedCohortResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**model_id** | **str** |  | [optional] 
**train_cohort_id** | **str** |  | [optional] 
**cohort_windows** | [**list[CohortWindow]**](CohortWindow.md) |  | 
**organization_id** | **str** |  | 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**revised_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

